Class: Lookout::Diff::Formats::Inline
- Includes:
- Enumerable
- Defined in:
- lib/lookout-3.0/diff/formats/inline.rb
Overview
Formats Operations inline in a String. Additions are shown as `+…+and deletions as[-…-]`. Replacements are shown as a deletion followed by an
insertion.
This format is used by Lookout::Difference::String for single-line Strings.
This format is inspired by the plain word “diff” format used by Git. That format was surely inspired by something before it, but it’s where I first saw it, so that’s what I’m referencing.
Defined Under Namespace
Classes: ToS
Instance Method Summary collapse
- #each {|to_s| ... } ⇒ Object
-
#to_s ⇒ Object
The concatenation of the formatted operations.