Module: Lookout::Difference
- Defined in:
- lib/lookout-3.0/difference.rb
Overview
Function-like namespace for type-specific difference reports. Used by
Expected and Expect to generate difference reports between their expected
values and actual results.
Object is the base class for all classes defined under this namespace, so
look to it for guidance.
Defined Under Namespace
Modules: Lookout
Classes: Array, Exception, Hash, Module, Object, Range, Regexp, String, Symbol